@@ -40,6 +40,7 @@ within that template.
 """
 
 from django import template
+from django.template import loader
 from django.db import models
 from django.core.cache import cache
 
@@ -50,26 +51,56 @@ CACHE_PREFIX = "flatblock_"
 
 class BasicFlatBlockWrapper(object):
     def prepare(self, parser, token):
+        """
+        The parser checks for following tag-configurations::
+            
+            {% flatblock {block} %}
+            {% flatblock {block} {timeout} %}
+            {% flatblock {block} using {tpl_name} %}
+            {% flatblock {block} {timeout} using {tpl_name} %}
+        """
         tokens = token.split_contents()
         self.is_variable = False
+        self.tpl_is_variable = False
         self.slug = None
-        if len(tokens) < 2 or len(tokens) > 3:
-            raise template.TemplateSyntaxError, "%r tag should have either 2 or 3 arguments" % (tokens[0],)
-        if len(tokens) == 2:
-            tag_name, slug = tokens
-            self.cache_time = 0
-        if len(tokens) == 3:
-            tag_name, slug, self.cache_time = tokens
-        # Check to see if the slug is properly double/single quoted
-        if not (slug[0] == slug[-1] and slug[0] in ('"', "'")):
-            self.is_variable = True
-            self.slug = slug
+        self.cache_time = 0
+        self.tpl_name = None
+        tag_name, self.slug, args = tokens[0], tokens[1], tokens[2:]
+        num_args = len(args)
+        if num_args == 0:
+            # Only the block name was specified
+            pass
+        elif num_args == 1:
+            # block and timeout
+            self.cache_time = args[0] 
+            pass
+        elif num_args == 2:
+            # block, "using", tpl_name
+            self.tpl_name = args[1]
+        elif num_args == 3:
+            # block, timeout, "using", tpl_name
+            self.cache_time = args[0]
+            self.tpl_name = args[2]
         else:
-            self.slug = slug[1:-1]
+            raise template.TemplateSyntaxError, "%r tag should have between 1 and 4 arguments" % (tokens[0],)
+        # Check to see if the slug is properly double/single quoted
+        if not (self.slug[0] == self.slug[-1] and self.slug[0] in ('"', "'")):
+            self.is_variable = True
+        else:
+            self.slug = self.slug[1:-1]
+        # Clean up the template name
+        if self.tpl_name is not None:
+            if not(self.tpl_name[0] == self.tpl_name[-1] and self.tpl_name[0] in ('"', "'")):
+                self.tpl_is_variable = True
+            else:
+                self.tpl_name = self.tpl_name[1:-1]
+        self.cache_time = int(self.cache_time)
     
     def __call__(self, parser, token):
         self.prepare(parser, token)
-        return FlatBlockNode(self.slug, self.is_variable, self.cache_time)
+        return FlatBlockNode(self.slug, self.is_variable, self.cache_time, 
+                template_name=self.tpl_name, 
+                tpl_is_variable=self.tpl_is_variable)
 
 class PlainFlatBlockWrapper(BasicFlatBlockWrapper):
     def __call__(self, parser, token):
@@ -80,17 +111,29 @@ do_get_flatblock = BasicFlatBlockWrapper()
 do_plain_flatblock = PlainFlatBlockWrapper()
     
 class FlatBlockNode(template.Node):
-    def __init__(self, slug, is_variable, cache_time=0, with_template=True):
-       self.slug = slug
-       self.is_variable = is_variable
-       self.cache_time = cache_time
-       self.with_template = with_template
+    def __init__(self, slug, is_variable, cache_time=0, with_template=True,
+            template_name=None, tpl_is_variable=False):
+        if template_name is None:
+            self.template_name = 'flatblocks/flatblock.html'
+        else:
+            if tpl_is_variable:
+                self.template_name = template.Variable(template_name)
+            else:
+                self.template_name = template_name
+        self.slug = slug
+        self.is_variable = is_variable
+        self.cache_time = cache_time
+        self.with_template = with_template
     
     def render(self, context):
         if self.is_variable:
             real_slug = template.Variable(self.slug).resolve(context)
         else:
             real_slug = self.slug
+        if isinstance(self.template_name, template.Variable):
+            real_template = self.template_name.resolve(context)
+        else:
+            real_template = self.template_name
         # Eventually we want to pass the whole context to the template so that
         # users have the maximum of flexibility of what to do in there.
         if self.with_template:
@@ -103,7 +146,7 @@ class FlatBlockNode(template.Node):
                 c = FlatBlock.objects.get(slug=real_slug)
                 cache.set(cache_key, c, int(self.cache_time))
             if self.with_template:
-                tmpl = template.loader.get_template('flatblocks/flatblock.html')
+                tmpl = loader.get_template(real_template)
                 new_ctx.update({'flatblock':c})
                 return tmpl.render(new_ctx)
             else:
@@ -112,4 +155,4 @@ class FlatBlockNode(template.Node):
             return ''
 
 register.tag('flatblock', do_get_flatblock)
-register.tag('plain_flatblock', do_plain_flatblock)
\ No newline at end of file
+register.tag('plain_flatblock', do_plain_flatblock)
